pub trait DeviceLocalServerHandler<___T: Transport = DriverChannel> {
// Required method
fn inject_events(
&mut self,
request: Request<InjectEvents, ___T>,
) -> impl Future<Output = ()>;
}Expand description
A server handler for the Device protocol.
See Device for more details.
Required Methods
Sourcefn inject_events(
&mut self,
request: Request<InjectEvents, ___T>,
) -> impl Future<Output = ()>
fn inject_events( &mut self, request: Request<InjectEvents, ___T>, ) -> impl Future<Output = ()>
Injects events into a target.
Batching: The caller is expected to batch-inject all events that share the same timestamp (e.g., multiple finger samples). There may be multiple such batches per injection call.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.